//+------------------------------------------------------------------+
//|                                           bar-close-alarm_V1.mq4 |
//|                                                          by mibl |
//+------------------------------------------------------------------+
//
// Indicator gives a sound signal or message when the next bar closes 
// within the denoted Time
// Indicator only reacts on the refreshment time of the chart. There
// is no realtime function used to estimate the totally correct time.

#property copyright "Copyright  2006, mibl"
#property indicator_chart_window

//---- input parameters
extern int MinutesBeforeCandleClose = 1;
extern string SoundWAV = "alert.wav";
extern ENUM_BASE_CORNER Corner = CORNER_LEFT_UPPER;
extern int FontSize = 10;
extern color FontColor = clrRed;
extern int XPosition = 10;
extern int YPosition = 20;
extern string UniqueID = "clock1";
extern bool alertsForNewBarOn = true;
extern bool alertsForTimeLessThanOn = true;
extern bool AlertOnNewBarFormed=true;
extern bool AlertEmail=false;
extern bool AlertPushNotification=false;
extern bool AlertMessage=true;
extern bool AlertSound=false;


//---- buffers
int MsgOnFlag = 1;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
   return(0);
  }
void deinit()
{
   ObjectDelete(UniqueID);
}  
  
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
  
   static int bars =0;
	int min, sec;
	
   min = Time[0] + Period()*60 - CurTime();
   sec = min%60;
   min =(min - min%60) / 60;
   string toDisplay = 
   ObjectDelete(UniqueID);
   ObjectCreate(UniqueID,OBJ_LABEL,0,0,0);
      ObjectSet(UniqueID,OBJPROP_CORNER,Corner);
      ObjectSet(UniqueID,OBJPROP_XDISTANCE,XPosition);
      ObjectSet(UniqueID,OBJPROP_YDISTANCE,YPosition);
      ObjectSetText(UniqueID,"" + min + " min " + sec + " sec",FontSize,"Arial",FontColor);
      if (AlertOnNewBarFormed)
      {
         if (alertsForNewBarOn && bars!=0 && bars!=Bars)
            {
               if (AlertMessage) Alert("new bar formed");
               if (AlertEmail) SendMail("clock-alert","new bar formed");
               if (AlertPushNotification) SendNotification("new bar formed");
               if (AlertSound) PlaySound(SoundWAV);
            }               
            bars=Bars;
      }         
	
	//Message or Sound min minutes before the candle closes
	if(min < MinutesBeforeCandleClose && MsgOnFlag == 1)
	{
	   if (alertsForTimeLessThanOn)
	   {
	      string message = timeFrameToString(Period())+" "+Symbol()+" - Less than " + min + " minute(s) " + sec + " second(s) to bar close!";
         if (AlertMessage) Alert(message);
         if (AlertEmail) SendMail("clock-alert",message);
         if (AlertPushNotification) SendNotification(message);
         if (AlertSound) PlaySound(SoundWAV);
      }         
	  MsgOnFlag = 0;
	}
	if(min > MinutesBeforeCandleClose) 
	{
	  MsgOnFlag = 1;
	}
	
   return(0);
  }
//+------------------------------------------------------------------+


//-------------------------------------------------------------------
//
//-------------------------------------------------------------------
//
//
//
//
//

string sTfTable[] = {"M1","M5","M15","M30","H1","H4","D1","W1","MN"};
int    iTfTable[] = {1,5,15,30,60,240,1440,10080,43200};

string timeFrameToString(int tf)
{
   for (int i=ArraySize(iTfTable)-1; i>=0; i--) 
         if (tf==iTfTable[i]) return(sTfTable[i]);
                              return("");
}